(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     24646,        560]
NotebookOptionsPosition[     25005,        549]
NotebookOutlinePosition[     25470,        569]
CellTagsIndexPosition[     25427,        566]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Force Projection onto a Line\n", "Title",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-08-25",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "Once we get a force, including its direction and magnitude, we can know its \
projection on a certain given line. \nIn the following example, we have two \
lines which passes points A, B and points A, C separately, thus we can define \
them as line AB and line AC. The direction of force is along line AC and \
starts from point A, also its magnitude can be set. Thus, we can show the \
projection of force ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "AC"], TraditionalForm]]],
 " on line AB. The magnitude of projection is given by "
}], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["F", "AB"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["F", "AC"], "cos\[Theta]"}]}], TraditionalForm]]]], "Text",
 TextAlignment->Center],

Cell["Where \[Theta] is the angle between line AB and line AC. ", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`f$$ = 7, $CellContext`opa0$$ = 
    1, $CellContext`opa2$$ = 0, $CellContext`opa3$$ = 0, $CellContext`opa4$$ =
     0, $CellContext`opa5$$ = 0, $CellContext`x1$$ = -3, $CellContext`x2$$ = 
    2, $CellContext`x3$$ = -3, $CellContext`y1$$ = -3, $CellContext`y2$$ = 
    4, $CellContext`y3$$ = 2, $CellContext`z1$$ = -3, $CellContext`z2$$ = 
    4, $CellContext`z3$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa0$$], 1, 
       Text[
        Style[
         Row[{"Coordinate visibility"}], 12]]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`x1$$], -3, 
       Style[
        Subscript[$CellContext`x, $CellContext`A], Italic]}, -5, 5}, {{
       Hold[$CellContext`y1$$], -3, 
       Style[
        Subscript[$CellContext`y, $CellContext`A], Italic]}, -5, 5}, {{
       Hold[$CellContext`z1$$], -3, 
       Style[
        Subscript[$CellContext`z, $CellContext`A], Italic]}, -5, 5}, {{
       Hold[$CellContext`x2$$], 2, 
       Style[
        Subscript[$CellContext`x, $CellContext`B], Italic]}, -5, 5}, {{
       Hold[$CellContext`y2$$], 4, 
       Style[
        Subscript[$CellContext`y, $CellContext`B], Italic]}, -5, 5}, {{
       Hold[$CellContext`z2$$], 4, 
       Style[
        Subscript[$CellContext`z, $CellContext`B], Italic]}, -5, 5}, {{
       Hold[$CellContext`x3$$], -3, 
       Style[
        Subscript[$CellContext`x, C], Italic]}, -5, 5}, {{
       Hold[$CellContext`y3$$], 2, 
       Style[
        Subscript[$CellContext`y, C], Italic]}, -5, 5}, {{
       Hold[$CellContext`z3$$], 4, 
       Style[
        Subscript[$CellContext`z, C], Italic]}, -5, 5}, {{
       Hold[$CellContext`f$$], 7, 
       Style[
        Subscript[$CellContext`F, $CellContext`AC], Italic]}, -20, 20}, {{
       Hold[$CellContext`opa2$$], 0, 
       Text[
        Style[
         Row[{"Show line AB", 
           Spacer[31]}], 12]]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa3$$], 0, 
       Text[
        Style[
         Row[{"Show line AC", 
           Spacer[30.5]}], 12]]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa4$$], 0, 
       Text[
        Style[
         Row[{"Show", 
           Spacer[3], 
           Subscript[$CellContext`F, $CellContext`AC], 
           Spacer[48]}], 12]]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa5$$], 0, 
       Text[
        Style[
         Row[{
           Column[{"Projection of", "force on line"}, Spacings -> 0.5], 
           Spacer[33]}], 12]]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Row[{
            Text[
             Style["Point A coordinate", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          Row[{
            Text[
             Style["Point B coordinate", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[5]}, {
          Manipulate`Place[6]}, {
          Manipulate`Place[7]}, {
          Row[{
            Text[
             Style["Point C coordinate", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[8]}, {
          Manipulate`Place[9]}, {
          Manipulate`Place[10]}, {
          Row[{
            Text[
             Style[
              Row[{"Magnitude of", 
                Spacer[3], 
                Subscript[$CellContext`F, $CellContext`AC]}], 12]]}, 
           Alignment -> Left]}, {
          Manipulate`Place[11]}, {
          Manipulate`Place[12]}, {
          Manipulate`Place[13]}, {
          Manipulate`Place[14]}, {
          Manipulate`Place[15]}, {
          Row[{
            Dynamic[
             If[
              And[$CellContext`opa5$$ == 1, 
               
               And[{$CellContext`x2$$ - $CellContext`x1$$, $CellContext`y2$$ - \
$CellContext`y1$$, $CellContext`z2$$ - $CellContext`z1$$} != {0, 0, 
                 0}, {$CellContext`x3$$ - $CellContext`x1$$, \
$CellContext`y3$$ - $CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$} != \
{0, 0, 0}]], $CellContext`temp1 = Row[{"\[Theta] = ", 
                 Dynamic[
                  NumberForm[N[
                    
                    VectorAngle[{$CellContext`x2$$ - $CellContext`x1$$, \
$CellContext`y2$$ - $CellContext`y1$$, $CellContext`z2$$ - \
$CellContext`z1$$}, {$CellContext`x3$$ - $CellContext`x1$$, $CellContext`y3$$ - \
$CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$}]] (180/Pi), {3, 
                   2}]], "\[Degree]"}], 
              Invisible[$CellContext`temp1]]], 
            Spacer[10], 
            Dynamic[
             If[
              And[$CellContext`opa5$$ == 1, 
               
               And[{$CellContext`x2$$ - $CellContext`x1$$, $CellContext`y2$$ - \
$CellContext`y1$$, $CellContext`z2$$ - $CellContext`z1$$} != {0, 0, 
                 0}, {$CellContext`x3$$ - $CellContext`x1$$, \
$CellContext`y3$$ - $CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$} != \
{0, 0, 0}]], $CellContext`temp2 = Row[{
                 Subscript[$CellContext`F, $CellContext`AB], " = ", 
                 Dynamic[
                  NumberForm[N[$CellContext`f$$] Cos[
                    
                    VectorAngle[{$CellContext`x2$$ - $CellContext`x1$$, \
$CellContext`y2$$ - $CellContext`y1$$, $CellContext`z2$$ - \
$CellContext`z1$$}, {$CellContext`x3$$ - $CellContext`x1$$, $CellContext`y3$$ - \
$CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$}]], {3, 2}]]}], 
              Invisible[$CellContext`temp2]]]}]}}, Alignment -> Left, 
        Spacings -> {Automatic, 0.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {540., {281., 289.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa0$53511$$ = False, $CellContext`x1$53512$$ = 
    0, $CellContext`y1$53513$$ = 0, $CellContext`z1$53514$$ = 
    0, $CellContext`x2$53515$$ = 0, $CellContext`y2$53516$$ = 
    0, $CellContext`z2$53517$$ = 0, $CellContext`x3$53518$$ = 
    0, $CellContext`y3$53519$$ = 0, $CellContext`z3$53520$$ = 
    0, $CellContext`f$53521$$ = 0, $CellContext`opa2$53522$$ = 
    False, $CellContext`opa3$53523$$ = False, $CellContext`opa4$53524$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`f$$ = 7, $CellContext`opa0$$ = 
        1, $CellContext`opa2$$ = 0, $CellContext`opa3$$ = 
        0, $CellContext`opa4$$ = 0, $CellContext`opa5$$ = 
        0, $CellContext`x1$$ = -3, $CellContext`x2$$ = 
        2, $CellContext`x3$$ = -3, $CellContext`y1$$ = -3, $CellContext`y2$$ = 
        4, $CellContext`y3$$ = 2, $CellContext`z1$$ = -3, $CellContext`z2$$ = 
        4, $CellContext`z3$$ = 4}, "ControllerVariables" :> {
        Hold[$CellContext`opa0$$, $CellContext`opa0$53511$$, False], 
        Hold[$CellContext`x1$$, $CellContext`x1$53512$$, 0], 
        Hold[$CellContext`y1$$, $CellContext`y1$53513$$, 0], 
        Hold[$CellContext`z1$$, $CellContext`z1$53514$$, 0], 
        Hold[$CellContext`x2$$, $CellContext`x2$53515$$, 0], 
        Hold[$CellContext`y2$$, $CellContext`y2$53516$$, 0], 
        Hold[$CellContext`z2$$, $CellContext`z2$53517$$, 0], 
        Hold[$CellContext`x3$$, $CellContext`x3$53518$$, 0], 
        Hold[$CellContext`y3$$, $CellContext`y3$53519$$, 0], 
        Hold[$CellContext`z3$$, $CellContext`z3$53520$$, 0], 
        Hold[$CellContext`f$$, $CellContext`f$53521$$, 0], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$53522$$, False], 
        Hold[$CellContext`opa3$$, $CellContext`opa3$53523$$, False], 
        Hold[$CellContext`opa4$$, $CellContext`opa4$53524$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`dwf0$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dw1$, $CellContext`dw2$, $CellContext`\
\[Alpha]$, $CellContext`size$, $CellContext`uf$, $CellContext`ul$, \
$CellContext`arc$, $CellContext`sc$, $CellContext`cos\[Theta]$, \
$CellContext`cf$, $CellContext`fl$, $CellContext`p$, $CellContext`pf$, \
$CellContext`pl$}, $CellContext`size$ = 5; $CellContext`sc$ = 
         0.8; $CellContext`ul$ = 
         Normalize[{$CellContext`x2$$ - $CellContext`x1$$, $CellContext`y2$$ - \
$CellContext`y1$$, $CellContext`z2$$ - $CellContext`z1$$}]; $CellContext`uf$ = 
         Normalize[{$CellContext`x3$$ - $CellContext`x1$$, $CellContext`y3$$ - \
$CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$}]; $CellContext`\
\[Alpha]$ = 
         If[(($CellContext`x2$$ - $CellContext`x1$$)^2 + ($CellContext`y2$$ - \
$CellContext`y1$$)^2 + ($CellContext`z2$$ - $CellContext`z1$$)^2) \
(($CellContext`x3$$ - $CellContext`x1$$)^2 + ($CellContext`y3$$ - \
$CellContext`y1$$)^2 + ($CellContext`z3$$ - $CellContext`z1$$)^2) != 0, 
           
           VectorAngle[{$CellContext`x2$$ - $CellContext`x1$$, \
$CellContext`y2$$ - $CellContext`y1$$, $CellContext`z2$$ - \
$CellContext`z1$$}, {$CellContext`x3$$ - $CellContext`x1$$, $CellContext`y3$$ - \
$CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$}], 
           0]; $CellContext`cf$ = {$CellContext`x1$$, $CellContext`y1$$, \
$CellContext`z1$$} + $CellContext`f$$ $CellContext`uf$; $CellContext`fl$ = \
{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$} + ($CellContext`f$$ \
$CellContext`ul$) 
           Cos[$CellContext`\[Alpha]$]; $CellContext`pf$ = $CellContext`fl$ + 
          0.1 ($CellContext`cf$ - $CellContext`fl$); $CellContext`pl$ = \
$CellContext`fl$ + 
          0.1 ({$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$} - \
$CellContext`fl$); $CellContext`p$ = $CellContext`pf$ + $CellContext`pl$ - \
$CellContext`fl$; $CellContext`arc$[
           PatternTest[
            Pattern[$CellContext`center, 
             Blank[]], VectorQ], {
            PatternTest[
             Pattern[$CellContext`start, 
              Blank[]], VectorQ], 
            PatternTest[
             Pattern[$CellContext`end, 
              Blank[]], VectorQ]}] := 
         Module[{$CellContext`ang, $CellContext`co, $CellContext`r}, \
$CellContext`ang = If[
              
              Or[$CellContext`start == $CellContext`center, $CellContext`end == \
$CellContext`center], 0, 
              
              VectorAngle[$CellContext`start - $CellContext`center, \
$CellContext`end - $CellContext`center]]; $CellContext`co = 
            Cos[$CellContext`ang/2]; $CellContext`r = 
            EuclideanDistance[$CellContext`center, $CellContext`start]; 
           BSplineCurve[{$CellContext`start, $CellContext`center + \
($CellContext`r/$CellContext`co) 
               Normalize[($CellContext`start + $CellContext`end)/
                  2 - $CellContext`center], $CellContext`end}, SplineDegree -> 
             2, SplineKnots -> {0, 0, 0, 1, 1, 1}, 
             SplineWeights -> {1, $CellContext`co, 1}]]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa0$$], 
           Dashing[{}], 
           Thickness[0.0025], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0, 0}, {$CellContext`size$, 0, 0}}], 
           Arrow[{{0, -$CellContext`size$, 0}, {0, $CellContext`size$, 0}}], 
           Arrow[{{0, 0, -$CellContext`size$}, {0, 0, $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            1.1 $CellContext`size$, (-0.05) $CellContext`size$, (-0.05) \
$CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             1.1 $CellContext`size$, 0.05 $CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, (-0.05) \
$CellContext`size$, 1.1 $CellContext`size$}]}; $CellContext`dwf1$ = {Black, 
           PointSize[0.015], 
           Point[{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$}], 
           Text[
            Style[
            "A", 12, 
             Bold], {$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$ + 
             0.5}], 
           Point[{$CellContext`x2$$, $CellContext`y2$$, $CellContext`z2$$}], 
           Text[
            Style[
            "B", 12, 
             Bold], {$CellContext`x2$$, $CellContext`y2$$, $CellContext`z2$$ + 
             0.5}], 
           Point[{$CellContext`x3$$, $CellContext`y3$$, $CellContext`z3$$}], 
           Text[
            Style[
            "C", 12, 
             Bold], {$CellContext`x3$$, $CellContext`y3$$, $CellContext`z3$$ + 
             0.5}]}; $CellContext`dwf2$ = {
           Opacity[$CellContext`opa2$$], Black, Dashed, 
           
           Line[{{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$}, \
{$CellContext`x2$$, $CellContext`y2$$, $CellContext`z2$$}}]}; \
$CellContext`dwf3$ = {
           Opacity[$CellContext`opa3$$], Black, Dashed, 
           
           Line[{{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$}, \
{$CellContext`x3$$, $CellContext`y3$$, $CellContext`z3$$}}]}; \
$CellContext`dwf4$ = {
           Opacity[$CellContext`opa4$$], Red, 
           Thickness[0.007], 
           Arrowheads[0.03], 
           
           Arrow[{{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$}, \
{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$} + $CellContext`f$$ \
$CellContext`uf$}]}; $CellContext`dwf5$ = {
           Opacity[$CellContext`opa5$$], Black, 
           Thickness[0.007], 
           Arrowheads[0.03], 
           
           Arrow[{{$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$}, \
$CellContext`fl$}], Dashed, 
           Line[{$CellContext`cf$, $CellContext`fl$}], 
           Dashing[{}], 
           Thickness[0.003], Red, 
           Text[
            Style[
            "\[Theta]", 
             10], {$CellContext`x1$$, $CellContext`y1$$, $CellContext`z1$$} + \
(1.5 (1/2)) ($CellContext`uf$ + $CellContext`ul$)], 
           $CellContext`arc$[{$CellContext`x1$$, $CellContext`y1$$, \
$CellContext`z1$$}, {$CellContext`ul$ + {$CellContext`x1$$, \
$CellContext`y1$$, $CellContext`z1$$}, $CellContext`uf$ + {$CellContext`x1$$, \
$CellContext`y1$$, $CellContext`z1$$}}], Black, 
           Dashing[{}], 
           Line[{$CellContext`p$, $CellContext`pf$}], 
           Line[{$CellContext`p$, $CellContext`pl$}]}; $CellContext`dwf6$ = {
           Opacity[0.5 $CellContext`opa5$$], Cyan, 
           
           Triangle[{{$CellContext`x1$$, $CellContext`y1$$, \
$CellContext`z1$$}, $CellContext`cf$, $CellContext`fl$}]}; $CellContext`dw1$ = 
         Graphics3D[{$CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$}, PlotRange -> 1.05 $CellContext`size$, Boxed -> False, 
           ViewPoint -> {
            0.5 $CellContext`size$, -$CellContext`size$, 
             0.5 $CellContext`size$}]; $CellContext`dw2$ = Graphics3D[{
            EdgeForm[], $CellContext`dwf6$}]; 
        Show[$CellContext`dw1$, $CellContext`dw2$]], 
      "Specifications" :> {{{$CellContext`opa0$$, 1, 
          Text[
           Style[
            Row[{"Coordinate visibility"}], 12]]}, {1 -> "On", 0 -> "Off"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         1}, {{$CellContext`x1$$, -3, 
          Style[
           Subscript[$CellContext`x, $CellContext`A], Italic]}, -5, 5, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         2}, {{$CellContext`y1$$, -3, 
          Style[
           Subscript[$CellContext`y, $CellContext`A], Italic]}, -5, 5, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         3}, {{$CellContext`z1$$, -3, 
          Style[
           Subscript[$CellContext`z, $CellContext`A], Italic]}, -5, 5, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         4}, {{$CellContext`x2$$, 2, 
          Style[
           Subscript[$CellContext`x, $CellContext`B], Italic]}, -5, 5, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         5}, {{$CellContext`y2$$, 4, 
          Style[
           Subscript[$CellContext`y, $CellContext`B], Italic]}, -5, 5, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         6}, {{$CellContext`z2$$, 4, 
          Style[
           Subscript[$CellContext`z, $CellContext`B], Italic]}, -5, 5, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         7}, {{$CellContext`x3$$, -3, 
          Style[
           Subscript[$CellContext`x, C], Italic]}, -5, 5, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         8}, {{$CellContext`y3$$, 2, 
          Style[
           Subscript[$CellContext`y, C], Italic]}, -5, 5, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         9}, {{$CellContext`z3$$, 4, 
          Style[
           Subscript[$CellContext`z, C], Italic]}, -5, 5, ImageSize -> Tiny, 
         Appearance -> "Labeled", ControlPlacement -> 
         10}, {{$CellContext`f$$, 7, 
          Style[
           Subscript[$CellContext`F, $CellContext`AC], Italic]}, -20, 20, 
         ImageSize -> Tiny, Appearance -> "Labeled", ControlPlacement -> 
         11}, {{$CellContext`opa2$$, 0, 
          Text[
           Style[
            Row[{"Show line AB", 
              Spacer[31]}], 12]]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 12}, {{$CellContext`opa3$$, 0, 
          Text[
           Style[
            Row[{"Show line AC", 
              Spacer[30.5]}], 12]]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 13}, {{$CellContext`opa4$$, 0, 
          Text[
           Style[
            Row[{"Show", 
              Spacer[3], 
              Subscript[$CellContext`F, $CellContext`AC], 
              Spacer[48]}], 12]]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 14}, {{$CellContext`opa5$$, 0, 
          Text[
           Style[
            Row[{
              Column[{"Projection of", "force on line"}, Spacings -> 0.5], 
              Spacer[33]}], 12]]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 15}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Row[{
             Text[
              Style["Point A coordinate", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           Row[{
             Text[
              Style["Point B coordinate", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[5]}, {
           Manipulate`Place[6]}, {
           Manipulate`Place[7]}, {
           Row[{
             Text[
              Style["Point C coordinate", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[8]}, {
           Manipulate`Place[9]}, {
           Manipulate`Place[10]}, {
           Row[{
             Text[
              Style[
               Row[{"Magnitude of", 
                 Spacer[3], 
                 Subscript[$CellContext`F, $CellContext`AC]}], 12]]}, 
            Alignment -> Left]}, {
           Manipulate`Place[11]}, {
           Manipulate`Place[12]}, {
           Manipulate`Place[13]}, {
           Manipulate`Place[14]}, {
           Manipulate`Place[15]}, {
           Row[{
             Dynamic[
              If[
               And[$CellContext`opa5$$ == 1, 
                
                And[{$CellContext`x2$$ - $CellContext`x1$$, $CellContext`y2$$ - \
$CellContext`y1$$, $CellContext`z2$$ - $CellContext`z1$$} != {0, 0, 
                  0}, {$CellContext`x3$$ - $CellContext`x1$$, \
$CellContext`y3$$ - $CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$} != \
{0, 0, 0}]], $CellContext`temp1 = Row[{"\[Theta] = ", 
                  Dynamic[
                   NumberForm[N[
                    
                    VectorAngle[{$CellContext`x2$$ - $CellContext`x1$$, \
$CellContext`y2$$ - $CellContext`y1$$, $CellContext`z2$$ - \
$CellContext`z1$$}, {$CellContext`x3$$ - $CellContext`x1$$, $CellContext`y3$$ - \
$CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$}]] (180/Pi), {3, 
                    2}]], "\[Degree]"}], 
               Invisible[$CellContext`temp1]]], 
             Spacer[10], 
             Dynamic[
              If[
               And[$CellContext`opa5$$ == 1, 
                
                And[{$CellContext`x2$$ - $CellContext`x1$$, $CellContext`y2$$ - \
$CellContext`y1$$, $CellContext`z2$$ - $CellContext`z1$$} != {0, 0, 
                  0}, {$CellContext`x3$$ - $CellContext`x1$$, \
$CellContext`y3$$ - $CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$} != \
{0, 0, 0}]], $CellContext`temp2 = Row[{
                  Subscript[$CellContext`F, $CellContext`AB], " = ", 
                  Dynamic[
                   NumberForm[N[$CellContext`f$$] Cos[
                    
                    VectorAngle[{$CellContext`x2$$ - $CellContext`x1$$, \
$CellContext`y2$$ - $CellContext`y1$$, $CellContext`z2$$ - \
$CellContext`z1$$}, {$CellContext`x3$$ - $CellContext`x1$$, $CellContext`y3$$ - \
$CellContext`y1$$, $CellContext`z3$$ - $CellContext`z1$$}]], {3, 2}]]}], 
               Invisible[$CellContext`temp2]]]}]}}, Alignment -> Left, 
         Spacings -> {Automatic, 0.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{892., {368., 377.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center,
 ExpressionUUID -> "fb376c2b-ac2d-4a77-8d2b-44e4f37e763d"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 265, 8, 230, "Title"],
Cell[1754, 45, 570, 11, 102, "Text"],
Cell[2327, 58, 205, 6, 45, "Text"],
Cell[2535, 66, 73, 0, 45, "Text"],
Cell[2611, 68, 22378, 478, 769, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature BvpWkjjvyDYOCAgTQC8iGtJT *)
